@@ -1,5 +1,4 @@
 import unittest
-import pandas as pd
 import pickle
 
 from htsexperimentation.compute_results.results_handler import ResultsHandler
@@ -46,10 +45,25 @@ class TestModel(unittest.TestCase):
             algorithms=["mint", "gpf_exact", "deepar"],
             groups=data[1],
         )
+        self.results_prison_no_version = ResultsHandler(
+            path="./results/",
+            dataset=self.datasets[0],
+            algorithms=["gpf_ngdpredloglike"],
+            groups=data[1],
+            use_version_to_search=False
+        )
 
-    def test_results_load(self):
-        res = self.results_prison.load_results_algorithm(
-            algorithm="ets_bu",
+    def test_results_load_gpf_variant(self):
+        res = self.results_prison_gpf.load_results_algorithm(
+            algorithm="gpf_sparse",
+            res_type="fitpred",
+            res_measure="mean",
+        )
+        self.assertTrue(res)
+
+    def test_results_load_gpf_variant_no_version(self):
+        res = self.results_prison_no_version.load_results_algorithm(
+            algorithm="gpf_ngdpredloglike",
             res_type="fitpred",
             res_measure="mean",
         )
@@ -73,7 +87,7 @@ class TestModel(unittest.TestCase):
         differences[self.results_tourism_gpf.dataset] = self.results_tourism_gpf.calculate_percent_diff(
             base_algorithm="gpf_exact", results=results
         )
-        boxplot(datasets_err=differences, err="rmse")
+        boxplot(datasets_err=differences, err="rmse", zeroline=True)
 
     def test_create_boxplot_all_algorithms(self):
         dataset_res = {}
@@ -101,7 +115,7 @@ class TestModel(unittest.TestCase):
             self.results_prison.h,
             "gpf_exact",
         )
-        mase_by_group = self.results_prison._compute_metric(
+        mase_by_group = self.results_prison._compute_metric_from_results(
             results_hierarchy, results_by_group_element, group_elements, "mase"
         )
         self.assertTrue(
@@ -114,7 +128,7 @@ class TestModel(unittest.TestCase):
             results_by_group_element,
             group_elements,
         ) = self.results_prison.compute_results_hierarchy(algorithm="mint")
-        mase_by_group = self.results_prison._compute_metric(
+        mase_by_group = self.results_prison._compute_metric_from_results(
             results_hierarchy, results_by_group_element, group_elements, "mase"
         )
         plot_mase(mase_by_group)
